% w = SIMPSON(f,a,b,N)
%
% summierte Simpsonregel zur Funktion f auf dem Intervall [a,b]
% und aequidistanten Unterteilung (N gerade)
% x_i = a + i * h, i = 0,1,...,N;   h = (b-a)/N 
%
%
% Input
% f       auszuwertende Funktion im Intervall [a,b]
% a,b     Intervallgrenzen a,b
% N       Anzahl Unterteilungen, N gerade. Das Intervall [a,b] wird in N
%         äquidistante Teilstücke eingeteilt
%
% Output  
% w       Wert der summierten Regel

function w = SIMPSON(f,a,b,N)
